@@ -47,7 +47,11 @@ const ApplicationRow = ({ comp, progress, progress_title, action }) => {
 
     let summary_or_progress;
     if (progress) {
-        summary_or_progress = <ProgressBar title={progress_title} data={progress} />;
+        summary_or_progress = (
+            <Flex spaceItems={{ default: 'spaceItemsSm' }} alignItems={{ default: 'alignItemsCenter' }}>
+                <span id={comp.name + "-progress"} className="progress-title-span">{progress_title}</span>
+                <ProgressBar title={progress_title} data={progress} ariaLabelledBy={comp.name + "-progress"} />
+            </Flex>);
     } else {
         if (error) {
             summary_or_progress = (
@@ -139,7 +143,7 @@ export const ApplicationList = ({ metainfo_db, appProgress, appProgressTitle, ac
         <Page id="list-page">
             <PageSection variant={PageSectionVariants.light}>
                 <Flex alignItems={{ default: 'alignItemsCenter' }}>
-                    <h2 className="pf-u-font-size-3xl">{_("Applications")}</h2>
+                    <h2 className="pf-v5-u-font-size-3xl">{_("Applications")}</h2>
                     <FlexItem align={{ default: 'alignRight' }}>
                         <Flex>
                             {refresh_progress}
