@@ -395,47 +395,6 @@ QUnit.test("not shared option", function (assert) {
     dbus2.close();
 });
 
-QUnit.test.skipWithPybridge("emit signal meta", function (assert) {
-    const done = assert.async();
-    assert.expect(4);
-
-    const meta = {
-        "borkety.Bork": {
-            signals: {
-                Bork: {
-                    in: ["i", "i", "i", "i", "s"]
-                }
-            }
-        }
-    };
-
-    let received = false;
-    const dbus = cockpit.dbus(null, { bus: "session", other: "option" });
-    dbus.meta(meta);
-    dbus.wait(function() {
-        dbus.subscribe({ path: "/bork", name: dbus.unique_name }, function(path, iface, signal, args) {
-            assert.equal(path, "/bork", "reflected path");
-            assert.equal(iface, "borkety.Bork", "reflected interface");
-            assert.equal(signal, "Bork", "reflected signal");
-            assert.deepEqual(args, [1, 2, 3, 4, "Bork"], "reflected arguments");
-            received = true;
-            dbus.close();
-            done();
-        });
-
-        dbus.addEventListener("close", function(event, ex) {
-            if (!received) {
-                console.log(ex);
-                assert.ok(false, "shouldn't fail");
-                done();
-            }
-        });
-
-        dbus.signal("/bork", "borkety.Bork", "Bork", [1, 2, 3, 4, "Bork"],
-                    { type: "iiiis" });
-    });
-});
-
 QUnit.test.skipWithPybridge("emit signal type", function (assert) {
     const done = assert.async();
     assert.expect(4);
@@ -484,243 +443,6 @@ QUnit.test.skipWithPybridge("emit signal no meta", function (assert) {
     dbus.signal("/bork", "borkety.Bork", "Bork", [1, 2, 3, 4, "Bork"]);
 });
 
-QUnit.test.skipWithPybridge("publish object", function (assert) {
-    const done = assert.async();
-    assert.expect(4);
-
-    const info = {
-        "org.Interface": {
-            methods: {
-                Add: { in: ["i", "i"], out: ["s"] },
-                Live: { in: ["s"] },
-            }
-        }
-    };
-
-    let received = null;
-
-    const object = {
-        Add: function(one, two) {
-            return String(one + two);
-        },
-        Live: function(input) {
-            received = input;
-        }
-    };
-
-    const dbus = cockpit.dbus(null, { bus: "session" });
-    dbus.meta(info);
-    dbus.wait().then(function() {
-        const published = dbus.publish("/a/path", "org.Interface", object);
-
-        published.then(function() {
-            assert.ok(true, "should resolve");
-        }, function() {
-            assert.ok(!true, "should not have failed");
-        });
-
-        /* Note that we're calling ourselves, but via the bus */
-        dbus.call("/a/path", "org.Interface", "Live", ["marmalade"], { name: dbus.unique_name });
-        dbus.call("/a/path", "org.Interface", "Add", [3, 44], { name: dbus.unique_name })
-                .then(function(reply) {
-                    assert.ok(published, "object was published");
-                    assert.deepEqual(reply, ["47"], "got back right reply");
-                    assert.strictEqual(received, "marmalade", "received right arguments");
-                }, function(ex) {
-                    assert.ok(false, "should not have failed");
-                })
-                .always(function() {
-                    dbus.close();
-                    done();
-                });
-    });
-});
-
-QUnit.test.skipWithPybridge("publish object promise", function (assert) {
-    const done = assert.async();
-    assert.expect(1);
-
-    const info = {
-        "org.Interface": {
-            methods: {
-                Add: { in: ["i", "i"], out: ["s", "i", "i"] },
-            }
-        }
-    };
-
-    const object = {
-        Add: function(one, two) {
-            const defer = cockpit.defer();
-            window.setTimeout(function() {
-                defer.resolve(String(one + two), one, two);
-            }, 200);
-            return defer.promise;
-        }
-    };
-
-    const dbus = cockpit.dbus(null, { bus: "session" });
-    dbus.meta(info);
-    dbus.wait().then(function() {
-        dbus.publish("/a/path", "org.Interface", object);
-
-        /* Note that we're calling ourselves, but via the bus */
-        dbus.call("/a/path", "org.Interface", "Add", [3, 44], { name: dbus.unique_name })
-                .then(function(reply) {
-                    assert.deepEqual(reply, ["47", 3, 44], "got back right reply");
-                }, function(ex) {
-                    assert.ok(false, "should not have failed");
-                })
-                .always(function() {
-                    dbus.close();
-                    done();
-                });
-    });
-});
-
-QUnit.test.skipWithPybridge("publish object failure", function (assert) {
-    const done = assert.async();
-    assert.expect(2);
-
-    const info = {
-        "org.Interface": {
-            methods: {
-                Fails: { in: ["i", "i"], out: ["s", "i", "i"] },
-            }
-        }
-    };
-
-    const object = {
-        Fails: function(one, two) {
-            const defer = cockpit.defer();
-            const ex = new Error("this is the message");
-            ex.name = "org.Error";
-            window.setTimeout(function() {
-                defer.reject(ex);
-            }, 5);
-            return defer.promise;
-        }
-    };
-
-    const dbus = cockpit.dbus(null, { bus: "session" });
-    dbus.meta(info);
-    dbus.wait().then(function() {
-        dbus.publish("/a/path", "org.Interface", object);
-
-        /* Note that we're calling ourselves, but via the bus */
-        dbus.call("/a/path", "org.Interface", "Fails", [3, 44], { name: dbus.unique_name })
-                .then(function(reply) {
-                    assert.ok(false, "should not have succeeded");
-                }, function(ex) {
-                    assert.strictEqual(ex.name, "org.Error", "got right error name");
-                    assert.strictEqual(ex.message, "this is the message", "got right error message");
-                })
-                .always(function() {
-                    dbus.close();
-                    done();
-                });
-    });
-});
-
-QUnit.test.skipWithPybridge("publish object replaces", function (assert) {
-    const done = assert.async();
-    assert.expect(2);
-
-    const info = {
-        "org.Interface": {
-            methods: {
-                Bonk: { in: ["s"], out: ["s"] },
-            }
-        }
-    };
-
-    const object1 = {
-        Bonk: function(input) {
-            return input + " bonked";
-        }
-    };
-
-    const object2 = {
-        Bonk: function(input) {
-            return "nope not bonked";
-        }
-    };
-
-    const dbus = cockpit.dbus(null, { bus: "session" });
-    dbus.meta(info);
-    dbus.wait().then(function() {
-        dbus.publish("/a/path", "org.Interface", object1);
-
-        /* Note that we're calling ourselves, but via the bus */
-        dbus.call("/a/path", "org.Interface", "Bonk", ["hi"], { name: dbus.unique_name })
-                .then(function(reply) {
-                    assert.deepEqual(reply, ["hi bonked"], "got back reply from first object");
-                    dbus.publish("/a/path", "org.Interface", object2);
-                    dbus.call("/a/path", "org.Interface", "Bonk", ["hi"], { name: dbus.unique_name })
-                            .then(function(reply) {
-                                assert.deepEqual(reply, ["nope not bonked"], "got back reply from second object");
-                            }, function() {
-                                assert.ok(false, "should not have failed");
-                            })
-                            .always(function() {
-                                dbus.close();
-                                done();
-                            });
-                }, function(ex) {
-                    assert.ok(false, "should not have failed");
-                });
-    });
-});
-
-QUnit.test.skipWithPybridge("publish object unpublish", function (assert) {
-    const done = assert.async();
-    assert.expect(4);
-
-    const info = {
-        "org.Interface": {
-            methods: {
-                Bonk: { in: ["s"], out: ["s"] },
-            }
-        }
-    };
-
-    const object = {
-        Bonk: function(input) {
-            return input + " bonked";
-        }
-    };
-
-    const dbus = cockpit.dbus(null, { bus: "session" });
-    dbus.meta(info);
-    dbus.wait().then(function() {
-        const published = dbus.publish("/a/path", "org.Interface", object);
-
-        /* Note that we're calling ourselves, but via the bus */
-        dbus.call("/a/path", "org.Interface", "Bonk", ["hi"], { name: dbus.unique_name })
-                .then(function(reply) {
-                    assert.deepEqual(reply, ["hi bonked"], "got back reply from first object");
-                    published.remove();
-
-                    dbus.call("/a/path", "org.Interface", "Bonk", ["hi"], { name: dbus.unique_name })
-                            .then(function(reply) {
-                                assert.ok(false, "should not have succeeded");
-                            }, function(ex) {
-                                assert.strictEqual(ex.name, "org.freedesktop.DBus.Error.UnknownMethod",
-                                                   "got right error name");
-                                assert.ok(ex.message.includes("No such interface") ||
-                                          ex.message.includes("Object does not exist"),
-                                          "unexpected error: " + ex.message);
-                                assert.ok(ex.message.indexOf("/a/path") > 0, "unexpected error: " + ex.message);
-                            })
-                            .always(function() {
-                                dbus.close();
-                                done();
-                            });
-                }, function(ex) {
-                    assert.ok(false, "should not have failed");
-                });
-    });
-});
-
 function internal_test(assert, options) {
     const done = assert.async();
     assert.expect(2);
