@@ -17,7 +17,7 @@
  * along with Cockpit; If not, see <http://www.gnu.org/licenses/>.
  */
 
-import '../lib/patternfly/patternfly-4-cockpit.scss';
+import '../lib/patternfly/patternfly-5-cockpit.scss';
 import 'cockpit-dark-theme'; // once per page
 import cockpit from "cockpit";
 import React, { useState } from 'react';
@@ -26,9 +26,9 @@ import { Alert } from "@patternfly/react-core/dist/esm/components/Alert/index.js
 import { Button } from "@patternfly/react-core/dist/esm/components/Button/index.js";
 import { Breadcrumb, BreadcrumbItem } from "@patternfly/react-core/dist/esm/components/Breadcrumb/index.js";
 import { Checkbox } from "@patternfly/react-core/dist/esm/components/Checkbox/index.js";
-import { Card, CardActions, CardBody, CardHeader, CardTitle } from "@patternfly/react-core/dist/esm/components/Card/index.js";
+import { Card, CardBody, CardHeader, CardTitle } from '@patternfly/react-core/dist/esm/components/Card/index.js';
 import { DataList, DataListCell, DataListCheck, DataListItem, DataListItemCells, DataListItemRow } from "@patternfly/react-core/dist/esm/components/DataList/index.js";
-import { Dropdown, DropdownItem, KebabToggle } from "@patternfly/react-core/dist/esm/components/Dropdown/index.js";
+import { Dropdown, DropdownItem, KebabToggle } from '@patternfly/react-core/dist/esm/deprecated/components/Dropdown/index.js';
 import { Flex, FlexItem } from "@patternfly/react-core/dist/esm/layouts/Flex/index.js";
 import { Form, FormGroup, FormHelperText } from "@patternfly/react-core/dist/esm/components/Form/index.js";
 import { Radio } from "@patternfly/react-core/dist/esm/components/Radio/index.js";
@@ -36,11 +36,12 @@ import { Stack } from "@patternfly/react-core/dist/esm/layouts/Stack/index.js";
 import { TextInput } from "@patternfly/react-core/dist/esm/components/TextInput/index.js";
 import { Title } from "@patternfly/react-core/dist/esm/components/Title/index.js";
 import { Toolbar, ToolbarContent, ToolbarItem } from "@patternfly/react-core/dist/esm/components/Toolbar/index.js";
-import { Page, PageSection, PageSectionVariants } from "@patternfly/react-core/dist/esm/components/Page/index.js";
+import { Page, PageBreadcrumb, PageSection, PageSectionVariants } from "@patternfly/react-core/dist/esm/components/Page/index.js";
 import { Modal } from "@patternfly/react-core/dist/esm/components/Modal/index.js";
 import { ExclamationCircleIcon } from '@patternfly/react-icons';
 
 import firewall from "./firewall-client.js";
+import { FormHelper } from "cockpit-components-form-helper";
 import { ListingTable } from 'cockpit-components-table.jsx';
 import { ModalError } from "cockpit-components-inline-notification.jsx";
 import { EmptyStatePanel } from "cockpit-components-empty-state.jsx";
@@ -67,7 +68,7 @@ const DeleteDropdown = ({ items, id }) => {
         {item.text}
     </DropdownItem>);
 
-    return (<Dropdown toggle={<KebabToggle onToggle={isOpen => setActionsKebabOpen(isOpen)} id={id || null} />}
+    return (<Dropdown toggle={<KebabToggle onToggle={(_event, isOpen) => setActionsKebabOpen(isOpen)} id={id || null} />}
                       isOpen={isActionsKebabOpen}
                       isPlain
                       position="right"
@@ -185,26 +186,25 @@ function ZoneSection(props) {
         </Button>
     );
 
+    const actions = !firewall.readonly && <div className="zone-section-buttons">{addServiceAction}{deleteButton}</div>;
+
     return <Card className="zone-section" data-id={props.zone.id}>
-        <CardHeader className="zone-section-heading">
-            <CardTitle>
-                <Flex alignItems={{ default: 'alignSelfBaseline' }} spaceItems={{ default: 'spaceItemsXl' }}>
-                    <Title headingLevel="h2" size="xl">
-                        { cockpit.format(_("$0 zone"), upperCaseFirstLetter(props.zone.name || props.zone.id)) }
-                    </Title>
-                    <Flex>
-                        { props.zone.interfaces.length > 0 &&
-                        <span>
-                            <strong>{cockpit.ngettext("Interface", "Interfaces", props.zone.interfaces.length)}</strong> {props.zone.interfaces.join(", ")}
-                        </span>
-                        }
-                        <span>
-                            <strong>{_("Allowed addresses")}</strong> {props.zone.source.length ? props.zone.source.join(", ") : _("Entire subnet")}
-                        </span>
-                    </Flex>
+        <CardHeader actions={{ actions }} className="zone-section-heading">
+            <Flex alignItems={{ default: 'alignSelfBaseline' }} spaceItems={{ default: 'spaceItemsXl' }}>
+                <CardTitle component="h2">
+                    { cockpit.format(_("$0 zone"), upperCaseFirstLetter(props.zone.name || props.zone.id)) }
+                </CardTitle>
+                <Flex>
+                    { props.zone.interfaces.length > 0 &&
+                    <span>
+                        <strong>{cockpit.ngettext("Interface", "Interfaces", props.zone.interfaces.length)}</strong> {props.zone.interfaces.join(", ")}
+                    </span>
+                    }
+                    <span>
+                        <strong>{_("Allowed addresses")}</strong> {props.zone.source.length ? props.zone.source.join(", ") : _("Entire subnet")}
+                    </span>
                 </Flex>
-            </CardTitle>
-            { !firewall.readonly && <CardActions className="zone-section-buttons">{addServiceAction}{deleteButton}</CardActions> }
+            </Flex>
         </CardHeader>
         {(props.zone.services.length > 0 || props.zone.ports.length > 0) &&
         <CardBody className="contains-list">
@@ -262,7 +262,7 @@ class SearchInput extends React.Component {
 
     render() {
         return (
-            <Toolbar>
+            <Toolbar className="filter-services-toolbar">
                 <ToolbarContent>
                     <ToolbarItem variant="label">
                         {_("Filter services")}
@@ -270,7 +270,7 @@ class SearchInput extends React.Component {
                     <ToolbarItem>
                         <TextInput type="search"
                                    id={this.props.id}
-                                   onChange={this.onValueChanged}
+                                   onChange={(_event, value) => this.onValueChanged(value)}
                                    value={this.state.value}
                         />
                     </ToolbarItem>
@@ -329,6 +329,7 @@ class AddEditServicesModal extends React.Component {
         };
         this.save = this.save.bind(this);
         this.edit = this.edit.bind(this);
+        this.checkNullValues = this.checkNullValues.bind(this);
         this.onFilterChanged = this.onFilterChanged.bind(this);
         this.onToggleService = this.onToggleService.bind(this);
         this.setId = this.setId.bind(this);
@@ -349,8 +350,15 @@ class AddEditServicesModal extends React.Component {
     }
 
     getCustomId() {
-        const all_ports = this.state.custom_tcp_ports.concat(this.state.custom_udp_ports);
-        return "custom--" + all_ports.map(this.getName).join('-');
+        return "custom--" + (
+            this.state.custom_tcp_ports.map(port => this.getName(port, "tcp"))
+                    .concat(this.state.custom_udp_ports.map(port => this.getName(port, "udp")))
+                    .join('-')
+        );
+    }
+
+    checkNullValues() {
+        return (!this.state.custom_tcp_value && !this.state.custom_udp_value);
     }
 
     edit(event) {
@@ -458,9 +466,9 @@ class AddEditServicesModal extends React.Component {
         });
     }
 
-    getName(port) {
+    getName(port, type) {
         const known = this.state.avail_services[port];
-        if (known)
+        if (known && known.type.includes(type))
             return known.name;
         else
             return port;
@@ -475,14 +483,12 @@ class AddEditServicesModal extends React.Component {
                 return [0, _("Invalid port number")];
             else
                 return [port, ""];
-        } else if (avail.type.indexOf(type) < 0)
-            return [0, _("Port number and type do not match")];
-        else {
+        } else {
             return [avail.port, ""];
         }
     }
 
-    validate(value, event) {
+    validate(event, value) {
         let error = "";
         let targets = ['tcp', 'custom_tcp_ports', 'tcp_error', 'custom_tcp_value'];
         if (event.target.id === "udp-ports")
@@ -525,13 +531,18 @@ class AddEditServicesModal extends React.Component {
                 [targets[3]]: value
             };
 
-            let all_ports = new_ports.concat(oldState.custom_udp_ports);
-            if (event_id === "udp-ports")
-                all_ports = oldState.custom_tcp_ports.concat(new_ports);
+            let all_ports;
+            if (event_id === "udp-ports") {
+                const old_ports = oldState.custom_tcp_ports.map(port => this.getName(port, "tcp"));
+                all_ports = old_ports.concat(new_ports.map(port => this.getName(port, "udp")));
+            } else {
+                const old_ports = oldState.custom_udp_ports.map(port => this.getName(port, "udp"));
+                all_ports = new_ports.map(port => this.getName(port, "tcp")).concat(old_ports);
+            }
 
             if (oldState.generate_custom_id) {
                 if (all_ports.length > 0)
-                    newState.custom_id = "custom--" + all_ports.map(this.getName).join('-');
+                    newState.custom_id = "custom--" + all_ports.join('-');
                 else
                     newState.custom_id = "";
             }
@@ -540,7 +551,7 @@ class AddEditServicesModal extends React.Component {
         });
     }
 
-    onToggleType(value, event) {
+    onToggleType(event) {
         this.setState({
             custom: event.target.value === "ports"
         });
@@ -599,7 +610,7 @@ class AddEditServicesModal extends React.Component {
                                isInline
                                title={_("Adding custom ports will reload firewalld. A reload will result in the loss of any runtime-only configuration!")} />
                        }
-                       <Button variant='primary' onClick={this.props.custom_id ? this.edit : this.save} aria-label={titleText}>
+                       <Button variant='primary' isDisabled={(this.state.custom && this.checkNullValues()) || (!this.state.custom && !this.state.selected.size)} onClick={this.props.custom_id ? this.edit : this.save} aria-label={titleText}>
                            {addText}
                        </Button>
                        <Button variant='link' className='btn-cancel' onClick={Dialogs.close}>
@@ -617,7 +628,7 @@ class AddEditServicesModal extends React.Component {
                                    id="add-services-dialog--services"
                                    value="services"
                                    isChecked={!this.state.custom}
-                                   onChange={this.onToggleType}
+                                   onChange={(_event, value) => this.onToggleType(value)}
                                    label={_("Services")} />
                             <Radio name="type"
                                    id="add-services-dialog--ports"
@@ -642,7 +653,7 @@ class AddEditServicesModal extends React.Component {
                                                     <DataListItemRow>
                                                         <DataListCheck aria-labelledby={s.id}
                                                                    isChecked={this.state.selected.has(s.id)}
-                                                                   onChange={(value, event) => this.onToggleService(event, s.id)}
+                                                                   onChange={(event, value) => this.onToggleService(event, s.id)}
                                                                    id={"firewall-service-" + s.id}
                                                                    name={s.id + "-checkbox"} />
                                                         <DataListItemCells
@@ -668,35 +679,32 @@ class AddEditServicesModal extends React.Component {
                     }
                     { !this.state.custom ||
                         <>
-                            <FormGroup label="TCP"
-                                       validated={this.state.tcp_error ? "error" : "default"}
-                                       helperText={_("Comma-separated ports, ranges, and services are accepted")}
-                                       helperTextInvalid={this.state.tcp_error}>
+                            <FormGroup label="TCP">
                                 <TextInput id="tcp-ports" type="text" onChange={this.validate}
                                            validated={this.state.tcp_error ? "error" : "default"}
                                            isDisabled={this.state.avail_services == null}
                                            value={this.state.custom_tcp_value}
                                            placeholder={_("Example: 22,ssh,8080,5900-5910")} />
+                                <FormHelper helperTextInvalid={this.state.tcp_error} helperText={_("Comma-separated ports, ranges, and services are accepted")} />
                             </FormGroup>
 
-                            <FormGroup label="UDP"
-                                       validated={this.state.udp_error ? "error" : "default"}
-                                       helperText={_("Comma-separated ports, ranges, and services are accepted")}
-                                       helperTextInvalid={this.state.udp_error}>
+                            <FormGroup label="UDP">
                                 <TextInput id="udp-ports" type="text" onChange={this.validate}
                                            validated={this.state.udp_error ? "error" : "default"}
                                            isDisabled={this.state.avail_services == null}
                                            value={this.state.custom_udp_value}
                                            placeholder={_("Example: 88,2019,nfs,rsync")} />
+                                <FormHelper helperTextInvalid={this.state.udp_error} helperText={_("Comma-separated ports, ranges, and services are accepted")} />
                             </FormGroup>
 
-                            <FormGroup label={_("ID")} helperText={_("If left empty, ID will be generated based on associated port services and port numbers")}>
-                                <TextInput id="service-name" onChange={this.setId} isDisabled={!!this.props.custom_id || this.state.avail_services == null}
+                            <FormGroup label={_("ID")}>
+                                <TextInput id="service-name" onChange={(_event, value) => this.setId(value)} isDisabled={!!this.props.custom_id || this.state.avail_services == null}
                                            value={this.state.custom_id} />
+                                <FormHelper helperText={_("If left empty, ID will be generated based on associated port services and port numbers")} />
                             </FormGroup>
 
                             <FormGroup label={_("Description")}>
-                                <TextInput id="service-description" onChange={this.setDescription} isDisabled={this.state.avail_services == null}
+                                <TextInput id="service-description" onChange={(_event, value) => this.setDescription(value)} isDisabled={this.state.avail_services == null}
                                            value={this.state.custom_description} />
                             </FormGroup>
                         </>
@@ -793,8 +801,8 @@ class ActivateZoneModal extends React.Component {
         });
         // https://networkmanager.dev/docs/api/latest/nm-dbus-types.html#NMDeviceCapabilities
         const NM_DEVICE_CAP_IS_SOFTWARE = 4;
-        const virtualDevices = interfaces.filter(i => i.capabilities & NM_DEVICE_CAP_IS_SOFTWARE !== 0 && i.device !== "lo").sort((a, b) => a.device.localeCompare(b.device));
-        const physicalDevices = interfaces.filter(i => (i.capabilities & NM_DEVICE_CAP_IS_SOFTWARE === 0) && i.device !== "lo").sort((a, b) => a.device.localeCompare(b.device));
+        const virtualDevices = interfaces.filter(i => (i.capabilities & NM_DEVICE_CAP_IS_SOFTWARE) !== 0 && i.device !== "lo").sort((a, b) => a.device.localeCompare(b.device));
+        const physicalDevices = interfaces.filter(i => ((i.capabilities & NM_DEVICE_CAP_IS_SOFTWARE) === 0) && i.device !== "lo").sort((a, b) => a.device.localeCompare(b.device));
         return (
             <Modal id="add-zone-dialog" isOpen
                    position="top" variant="medium"
@@ -823,7 +831,7 @@ class ActivateZoneModal extends React.Component {
                                         .map(z =>
                                             <Radio key={z} id={z} name="zone" value={z}
                                                    isChecked={this.state.zone == z}
-                                                   onChange={(value, e) => this.onChange("zone", e.target.value)}
+                                                   onChange={e => this.onChange("zone", e.target.value)}
                                                    label={ firewall.zones[z].id } />
                                         )}
                             </FlexItem>
@@ -832,7 +840,7 @@ class ActivateZoneModal extends React.Component {
                                 { customZones.map(z =>
                                     <Radio key={z} id={z} name="zone" value={z}
                                            isChecked={this.state.zone == z}
-                                           onChange={(value, e) => this.onChange("zone", e.target.value)}
+                                           onChange={e => this.onChange("zone", e.target.value)}
                                            label={ firewall.zones[z].id } />
                                 )}
                             </FlexItem>
@@ -849,7 +857,7 @@ class ActivateZoneModal extends React.Component {
                         <div id="add-zone-services-readonly">
                             { (this.state.zone && firewall.zones[this.state.zone].services.join(", ")) || _("None") }
                         </div>
-                        <FormHelperText isHidden={false}>{_("The cockpit service is automatically included")}</FormHelperText>
+                        <FormHelper helperText={_("The cockpit service is automatically included")} />
                     </FormGroup>
 
                     <FormGroup label={ _("Interfaces") } hasNoPaddingTop isInline>
@@ -857,14 +865,14 @@ class ActivateZoneModal extends React.Component {
                             <Checkbox key={i.device}
                                       id={i.device}
                                       value={i.device}
-                                      onChange={(value, event) => this.onInterfaceChange(event)}
+                                      onChange={(event, value) => this.onInterfaceChange(event)}
                                       isChecked={this.state.interfaces.has(i.device)}
                                       label={i.device} />) }
                         { virtualDevices.map(i =>
                             <Checkbox key={i.device}
                                       id={i.device}
                                       value={i.device}
-                                      onChange={(value, event) => this.onInterfaceChange(event)}
+                                      onChange={(event, value) => this.onInterfaceChange(event)}
                                       isChecked={this.state.interfaces.has(i.device)}
                                       label={i.device} />) }
                     </FormGroup>
@@ -874,16 +882,20 @@ class ActivateZoneModal extends React.Component {
                                isChecked={this.state.ipRange == "ip-entire-subnet"}
                                value="ip-entire-subnet"
                                id="ip-entire-subnet"
-                               onChange={(value, e) => this.onChange("ipRange", e.target.value)}
+                               onChange={e => this.onChange("ipRange", e.target.value)}
                                label={ _("Entire subnet") } />
                         <Radio name="add-zone-ip"
                                isChecked={this.state.ipRange == "ip-range"}
                                value="ip-range"
                                id="ip-range"
-                               onChange={(value, e) => this.onChange("ipRange", e.target.value)}
+                               onChange={e => this.onChange("ipRange", e.target.value)}
                                label={ _("Range") } />
-                        { this.state.ipRange === "ip-range" && <TextInput id="add-zone-ip" onChange={value => this.onChange("ipRangeValue", value)} /> }
-                        <FormHelperText isHidden={this.state.ipRange != "ip-range"}>{_("IP address with routing prefix. Separate multiple values with a comma. Example: 192.0.2.0/24, 2001:db8::/32")}</FormHelperText>
+                        {this.state.ipRange === "ip-range" && (
+                            <>
+                                <TextInput id="add-zone-ip" onChange={(_event, value) => this.onChange("ipRangeValue", value)} />
+                                <FormHelperText>{_("IP address with routing prefix. Separate multiple values with a comma. Example: 192.0.2.0/24, 2001:db8::/32")}</FormHelperText>
+                            </>
+                        )}
                     </FormGroup>
                 </Form>
             </Modal>
@@ -1039,26 +1051,25 @@ export class Firewall extends React.Component {
         const enabled = this.state.firewall.enabled;
 
         return (
-            <Page groupProps={{ sticky: 'top' }}
-                  isBreadcrumbGrouped
-                  breadcrumb={
-                      <Breadcrumb>
-                          <BreadcrumbItem onClick={go_up} className="pf-c-breadcrumb__link">{_("Networking")}</BreadcrumbItem>
-                          <BreadcrumbItem isActive>{_("Firewall")}</BreadcrumbItem>
-                      </Breadcrumb>}
-                  additionalGroupedContent={
-                      <PageSection id="firewall-heading" variant={PageSectionVariants.light} className="firewall-heading">
-                          <Flex alignItems={{ default: 'alignItemsCenter' }} justifyContent={{ default: 'justifyContentSpaceBetween' }}>
-                              <Flex alignItems={{ default: 'alignItemsCenter' }} id="firewall-heading-title-group">
-                                  <Title headingLevel="h2" size="3xl">
-                                      {_("Firewall")}
-                                  </Title>
-                                  <FirewallSwitch firewall={firewall} />
-                                  <p>{_("Incoming requests are blocked by default. Outgoing requests are not blocked.")}</p>
-                              </Flex>
-                              { enabled && !firewall.readonly && <span className="btn-group">{addZoneAction}</span> }
-                          </Flex>
-                      </PageSection>}>
+            <Page>
+                <PageBreadcrumb stickyOnBreakpoint={{ default: "top" }}>
+                    <Breadcrumb>
+                        <BreadcrumbItem onClick={go_up} className="pf-v5-c-breadcrumb__link">{_("Networking")}</BreadcrumbItem>
+                        <BreadcrumbItem isActive>{_("Firewall")}</BreadcrumbItem>
+                    </Breadcrumb>
+                </PageBreadcrumb>
+                <PageSection id="firewall-heading" variant={PageSectionVariants.light} className="firewall-heading">
+                    <Flex alignItems={{ default: 'alignItemsCenter' }} justifyContent={{ default: 'justifyContentSpaceBetween' }}>
+                        <Flex alignItems={{ default: 'alignItemsCenter' }} id="firewall-heading-title-group">
+                            <Title headingLevel="h2" size="3xl">
+                                {_("Firewall")}
+                            </Title>
+                            <FirewallSwitch firewall={firewall} />
+                            <p>{_("Incoming requests are blocked by default. Outgoing requests are not blocked.")}</p>
+                        </Flex>
+                        { enabled && !firewall.readonly && <span className="btn-group">{addZoneAction}</span> }
+                    </Flex>
+                </PageSection>
                 <PageSection id="zones-listing">
                     { enabled && <Stack hasGutter>
                         {
