@@ -20,7 +20,7 @@
 import cockpit from "cockpit";
 import React from "react";
 
-import { Card, CardActions, CardBody, CardHeader, CardTitle } from "@patternfly/react-core/dist/esm/components/Card/index.js";
+import { Card, CardBody, CardHeader, CardTitle } from '@patternfly/react-core/dist/esm/components/Card/index.js';
 import { Checkbox } from "@patternfly/react-core/dist/esm/components/Checkbox/index.js";
 import { ClipboardCopy } from "@patternfly/react-core/dist/esm/components/ClipboardCopy/index.js";
 import { Form, FormGroup } from "@patternfly/react-core/dist/esm/components/Form/index.js";
@@ -39,13 +39,13 @@ import {
     dialog_open,
     SelectOneRadio, TextInput, PassInput, Skip
 } from "./dialog.jsx";
-import { array_find, decode_filename, encode_filename, block_name, for_each_async } from "./utils.js";
+import { decode_filename, encode_filename, block_name, for_each_async, get_children } from "./utils.js";
 import { fmt_to_fragments } from "utils.jsx";
 import { StorageButton } from "./storage-controls.jsx";
 import { parse_options, unparse_options } from "./format-dialog.jsx";
 import { edit_config } from "./crypto-tab.jsx";
 
-import clevis_luks_passphrase_sh from "raw-loader!./clevis-luks-passphrase.sh";
+import clevis_luks_passphrase_sh from "./clevis-luks-passphrase.sh";
 
 const _ = cockpit.gettext;
 
@@ -56,7 +56,7 @@ function get_tang_adv(url) {
     return cockpit.spawn(["curl", "-sSf", url + "/adv"], { err: "message" })
             .then(JSON.parse)
             .catch(error => {
-                return cockpit.reject(error.toString().replace(/^curl: \([0-9]+\) /, ""));
+                return Promise.reject(error.toString().replace(/^curl: \([0-9]+\) /, ""));
             });
 }
 
@@ -208,7 +208,7 @@ export function existing_passphrase_fields(explanation) {
 }
 
 function get_stored_passphrase(block, just_type) {
-    const pub_config = array_find(block.Configuration, function (c) { return c[0] == "crypttab" });
+    const pub_config = block.Configuration.find(c => c[0] == "crypttab");
     if (pub_config && pub_config[1]["passphrase-path"] && decode_filename(pub_config[1]["passphrase-path"].v) != "") {
         if (just_type)
             return Promise.resolve("stored");
@@ -303,6 +303,21 @@ function ensure_package_installed(steps, progress, package_name) {
                                 return install_missing_packages(data, status_callback(progress));
                         }
                     });
+            })
+            .catch(error => {
+            // Something wrong with PackageKit, maybe it is not even
+            // installed.  Let's show the error during fixing.
+                progress(null, null);
+                steps.push({
+                    title: cockpit.format(_("The $0 package must be installed."), package_name),
+                    func: progress => {
+                        if (error.problem == "not-found") {
+                            return Promise.reject(cockpit.format(_("Error installing $0: PackageKit is not installed"), package_name));
+                        } else {
+                            return Promise.reject(cockpit.format(_("Unexpected PackageKit error during installation of $0: $1"), package_name, error.toString())); // not-covered: OS error
+                        }
+                    }
+                });
             });
 }
 
@@ -338,9 +353,9 @@ function ensure_root_nbde_support(steps, progress) {
 function ensure_fstab_option(steps, progress, client, block, option) {
     const cleartext = client.blocks_cleartext[block.path];
     const crypto = client.blocks_crypto[block.path];
-    const fsys_config = (cleartext
-        ? array_find(cleartext.Configuration, function (c) { return c[0] == "fstab" })
-        : array_find(crypto.ChildConfiguration, function (c) { return c[0] == "fstab" }));
+    const fsys_config = cleartext
+        ? cleartext.Configuration.find(c => c[0] == "fstab")
+        : crypto?.ChildConfiguration.find(c => c[0] == "fstab");
     const fsys_options = fsys_config && parse_options(decode_filename(fsys_config[1].opts.v));
 
     if (!fsys_options || fsys_options.indexOf(option) >= 0)
@@ -362,7 +377,7 @@ function ensure_fstab_option(steps, progress, client, block, option) {
 }
 
 function ensure_crypto_option(steps, progress, client, block, option) {
-    const crypto_config = array_find(block.Configuration, function (c) { return c[0] == "crypttab" });
+    const crypto_config = block.Configuration.find(c => c[0] == "crypttab");
     const crypto_options = crypto_config && parse_options(decode_filename(crypto_config[1].options.v));
     if (!crypto_options || crypto_options.indexOf(option) >= 0)
         return Promise.resolve();
@@ -395,15 +410,26 @@ function ensure_non_root_nbde_support(steps, progress, client, block) {
             .then(() => ensure_crypto_option(steps, progress, client, block, "_netdev"));
 }
 
-function ensure_nbde_support(steps, progress, client, block) {
-    const cleartext = client.blocks_cleartext[block.path];
-    const crypto = client.blocks_crypto[block.path];
-    const fsys_config = (cleartext
-        ? array_find(cleartext.Configuration, function (c) { return c[0] == "fstab" })
-        : array_find(crypto.ChildConfiguration, function (c) { return c[0] == "fstab" }));
-    const dir = decode_filename(fsys_config[1].dir.v);
+function contains_rootfs(client, path) {
+    const block = client.blocks[path];
+    const crypto = client.blocks_crypto[path];
+    let fsys_config = null;
 
-    if (dir == "/") {
+    if (block)
+        fsys_config = block.Configuration.find(c => c[0] == "fstab");
+    if (!fsys_config && crypto)
+        fsys_config = crypto.ChildConfiguration.find(c => c[0] == "fstab");
+
+    if (fsys_config) {
+        const dir = decode_filename(fsys_config[1].dir.v);
+        return dir == "/";
+    }
+
+    return get_children(client, path).some(p => contains_rootfs(client, p));
+}
+
+function ensure_nbde_support(steps, progress, client, block) {
+    if (contains_rootfs(client, block.path)) {
         if (client.get_config("nbde_root_help", false)) {
             steps.is_root = true;
             return ensure_root_nbde_support(steps, progress);
@@ -658,13 +684,13 @@ const RemovePassphraseField = (tag, key, dev) => {
                         <Checkbox id="force-remove-passphrase"
                                   isChecked={val !== false}
                                   label={_("Confirm removal with an alternate passphrase")}
-                                  onChange={checked => change(checked ? "" : false)}
+                                  onChange={(_event, checked) => change(checked ? "" : false)}
                                   body={val === false
                                       ? <p className="slot-warning">
                                           {_("Removing a passphrase without confirmation of another passphrase may prevent unlocking or key management, if other passphrases are forgotten or lost.")}
                                       </p>
                                       : <FormGroup label={_("Passphrase from any other key slot")} fieldId="remove-passphrase">
-                                          <TextInputPF id="remove-passphrase" type="password" value={val} onChange={value => change(value)} />
+                                          <TextInputPF id="remove-passphrase" type="password" value={val} onChange={(_event, value) => change(value)} />
                                       </FormGroup>
                                   }
                         />
@@ -836,20 +862,21 @@ export class CryptoKeyslots extends React.Component {
 
         return (
             <Card className="key-slot-panel">
-                <CardHeader>
-                    <CardActions>
+                <CardHeader actions={{
+                    actions: <>
                         <span className="key-slot-panel-remaining">
                             { remaining < 6 ? (remaining ? cockpit.format(cockpit.ngettext("$0 slot remains", "$0 slots remain", remaining), remaining) : _("No available slots")) : null }
                         </span>
                         <StorageButton onClick={() => add_dialog(client, block)}
-                                       ariaLabel={_("Add")}
-                                       excuse={(keys.length == max_slots)
-                                           ? _("No free key slots")
-                                           : null}>
+                                           ariaLabel={_("Add")}
+                                           excuse={(keys.length == max_slots)
+                                               ? _("No free key slots")
+                                               : null}>
                             <PlusIcon />
                         </StorageButton>
-                    </CardActions>
-                    <CardTitle><Text component={TextVariants.h2}>{_("Keys")}</Text></CardTitle>
+                    </>,
+                }}>
+                    <CardTitle component="h2">{_("Keys")}</CardTitle>
                 </CardHeader>
                 <CardBody className="contains-list">
                     <DataList isCompact className="crypto-keyslots-list" aria-label={_("Keys")}>
