@@ -61,13 +61,6 @@ export function mock_hostnamed(value) {
     }
 }
 
-export function array_find(array, pred) {
-    for (let i = 0; i < array.length; i++)
-        if (pred(array[i]))
-            return array[i];
-    return undefined;
-}
-
 export function flatten(array_of_arrays) {
     if (array_of_arrays.length > 0)
         return Array.prototype.concat.apply([], array_of_arrays);
@@ -460,7 +453,7 @@ export function get_available_spaces(client) {
 export function prepare_available_spaces(client, spcs) {
     function prepare(spc) {
         if (spc.type == 'block')
-            return cockpit.resolve(spc.block.path);
+            return Promise.resolve(spc.block.path);
         else if (spc.type == 'free') {
             const block_ptable = client.blocks_ptable[spc.block.path];
             return block_ptable.CreatePartition(spc.start, spc.size, "", "", { });
@@ -576,7 +569,20 @@ export function is_netdev(client, path) {
     return false;
 }
 
-function get_children(client, path) {
+/* GET_CHILDREN gets the direct children of the storage object at
+   PATH, like the partitions of a partitioned block device, or the
+   volume group of a physical volume.  By calling GET_CHILDREN
+   recursively, you can traverse the whole storage hierachy from
+   hardware drives at the bottom to filesystems at the top.
+
+   GET_CHILDREN_FOR_TEARDOWN is similar but doesn't consider things
+   like volume groups to be children of their physical volumes.  This
+   is appropriate for teardown processing, where tearing down a
+   physical volume does not imply tearing down the whole volume groups
+   with everything that it contains.
+*/
+
+function get_children_for_teardown(client, path) {
     const children = [];
 
     if (client.blocks_cleartext[path]) {
@@ -624,6 +630,30 @@ function get_children(client, path) {
     return children;
 }
 
+export function get_children(client, path) {
+    const children = get_children_for_teardown(client, path);
+
+    if (client.blocks[path]) {
+        const mdraid = client.blocks[path].MDRaidMember;
+        if (mdraid != "/")
+            children.push(mdraid);
+    }
+
+    if (client.blocks_pvol[path]) {
+        const vgroup = client.blocks_pvol[path].VolumeGroup;
+        if (vgroup != "/")
+            children.push(vgroup);
+    }
+
+    if (client.blocks_stratis_blockdev[path]) {
+        const pool = client.blocks_stratis_blockdev[path].Pool;
+        if (pool != "/")
+            children.push(pool);
+    }
+
+    return children;
+}
+
 export function get_active_usage(client, path, top_action, child_action) {
     function get_usage(path, level) {
         const block = client.blocks[path];
@@ -635,7 +665,7 @@ export function get_active_usage(client, path, top_action, child_action) {
         const stratis_blockdev = block && client.blocks_stratis_blockdev[path];
         const stratis_pool = stratis_blockdev && client.stratis_pools[stratis_blockdev.Pool];
 
-        const usage = flatten(get_children(client, path).map(p => get_usage(p, level + 1)));
+        const usage = flatten(get_children_for_teardown(client, path).map(p => get_usage(p, level + 1)));
 
         function get_actions(teardown_action) {
             const actions = [];
@@ -659,9 +689,7 @@ export function get_active_usage(client, path, top_action, child_action) {
                 });
             });
         } else if (mdraid) {
-            const active_state = array_find(mdraid.ActiveDevices, function (as) {
-                return as[0] == block.path;
-            });
+            const active_state = mdraid.ActiveDevices.find(as => as[0] == block.path);
             usage.push({
                 level,
                 usage: 'mdraid-member',
