@@ -439,7 +439,7 @@ function WorkflowRow(props) {
         <Split hasGutter>
             <SplitItem>{props.label}</SplitItem>
             <SplitItem isFilled>
-                {props.problemState === ProblemState.REPORTING && <Spinner isSVG size="md" /> }
+                {props.problemState === ProblemState.REPORTING && <Spinner size="md" /> }
                 {status}
             </SplitItem>
             <SplitItem>{button}</SplitItem>
@@ -472,7 +472,7 @@ export class ReportingTable extends React.Component {
     render() {
         return (
             <Card>
-                <CardTitle><h2>{_("Crash reporting")}</h2></CardTitle>
+                <CardTitle component="h2">{_("Crash reporting")}</CardTitle>
                 <CardBody>
                     <FAFWorkflowRow problem={this.props.problem} />
                     {
