@@ -504,6 +504,7 @@ map_gssapi_to_local (gss_name_t name,
             }
           else
             {
+              assert (display.value != NULL);
               str = strndupx (display.value, display.length); /* display names are not allowed to contain \0 */
               if (getpwnam (str))
                 {
@@ -907,15 +908,12 @@ main (int argc,
   if (isatty (0))
     errx (2, "this command is not meant to be run from the console");
 
-  /* COMPAT: argv[1] used ot be used, but is now ignored */
+  /* COMPAT: argv[1] used to be used, but is now ignored */
   if (argc != 1 && argc != 2)
     errx (2, "invalid arguments to cockpit-session");
 
   program_name = basename (argv[0]);
 
-  /* Cleanup the umask */
-  umask (077);
-
   rhost = getenv ("COCKPIT_REMOTE_PEER") ?: "";
 
   save_environment ();
