@@ -23,12 +23,12 @@ import textwrap
 from testlib import Error, MachineCase, wait
 
 
-def from_udisks_ascii(bytes):
-    return ''.join(map(chr, bytes[:-1]))
+def from_udisks_ascii(codepoints):
+    return ''.join(map(chr, codepoints[:-1]))
 
 
 class StorageHelpers:
-    '''Mix-in class for using in tests that derive from something else than MachineCase or StorageCase'''
+    """Mix-in class for using in tests that derive from something else than MachineCase or StorageCase"""
 
     def inode(self, f):
         return self.machine.execute("stat -L '%s' -c %%i" % f)
@@ -46,12 +46,12 @@ class StorageHelpers:
         self.browser.wait(step)
 
     def add_ram_disk(self, size=50):
-        '''Add per-test RAM disk
+        """Add per-test RAM disk
 
         The disk gets removed automatically when the test ends. This is safe for @nondestructive tests.
 
         Return the device name.
-        '''
+        """
         # sanity test: should not yet be loaded
         self.machine.execute("test ! -e /sys/module/scsi_debug")
         self.machine.execute(f"modprobe scsi_debug dev_size_mb={size}")
@@ -62,7 +62,7 @@ class StorageHelpers:
         return dev
 
     def add_loopback_disk(self, size=50, name=None):
-        '''Add per-test loopback disk
+        """Add per-test loopback disk
 
         The disk gets removed automatically when the test ends. This is safe for @nondestructive tests.
 
@@ -71,7 +71,7 @@ class StorageHelpers:
         simulation of a "real" disk.
 
         Return the device name.
-        '''
+        """
         # HACK: https://bugzilla.redhat.com/show_bug.cgi?id=1969408
         # It would be nicer to remove $F immediately after the call to
         # losetup, but that will break some versions of lvm2.
@@ -88,35 +88,35 @@ class StorageHelpers:
         return dev
 
     def force_remove_disk(self, device):
-        '''Act like the given device gets physically removed.
+        """Act like the given device gets physically removed.
 
         This circumvents all the normal EBUSY failures, and thus can be used for testing
         the cleanup after a forceful removal.
-        '''
+        """
         self.machine.execute(f'echo 1 > /sys/block/{os.path.basename(device)}/device/delete')
 
     def devices_dropdown(self, title):
-        self.browser.click("#devices .pf-c-dropdown button.pf-c-dropdown__toggle")
-        self.browser.click(f"#devices .pf-c-dropdown a:contains('{title}')")
+        self.browser.click("#devices .pf-v5-c-dropdown button.pf-v5-c-dropdown__toggle")
+        self.browser.click(f"#devices .pf-v5-c-dropdown a:contains('{title}')")
 
     # Content
 
     def content_row_tbody(self, index):
-        return "#detail-content > article > div > table > tbody:nth-of-type(%d)" % index
+        return "#detail-content > .pf-v5-c-card > div > table > tbody:nth-of-type(%d)" % index
 
     def content_row_expand(self, index):
         b = self.browser
         tbody = self.content_row_tbody(index)
         b.wait_visible(tbody)
         if "pf-m-expanded" not in (b.attr(tbody, "class") or ""):
-            b.click(tbody + " tr td.pf-c-table__toggle button")
+            b.click(tbody + " tr td.pf-v5-c-table__toggle button")
             b.wait_visible(tbody + ".pf-m-expanded")
 
     def content_row_action(self, index, title, isExpandable=True):
         if isExpandable:
             btn = self.content_row_tbody(index) + f" tr:first-child td button:contains({title})"
         else:
-            btn = "#detail-content > article > div > table > :nth-child(%d)" % index + f" td button:contains({title})"
+            btn = "#detail-content > .pf-v5-c-card > div > table > :nth-child(%d)" % index + f" td button:contains({title})"
         self.browser.click(btn)
 
     # The row might come and go a couple of times until it has the
@@ -127,19 +127,19 @@ class StorageHelpers:
         if isExpandable:
             col = self.content_row_tbody(row_index) + " tr:first-child > :nth-child(%d)" % (col_index + 1)
         else:
-            col = "#detail-content > article > div > table > :nth-child(%d)" % row_index + " > :nth-child(%d)" % (col_index + 1)
+            col = "#detail-content > .pf-v5-c-card > div > table > :nth-child(%d)" % row_index + " > :nth-child(%d)" % (col_index + 1)
         wait(lambda: self.browser.is_present(col) and (val in self.browser.text(col) or (alternate_val and alternate_val in self.browser.text(col))))
 
     def content_dropdown_action(self, index, title, isExpandable=True):
         if isExpandable:
-            dropdown = self.content_row_tbody(index) + " tr td:last-child .pf-c-dropdown"
+            dropdown = self.content_row_tbody(index) + " tr td:last-child .pf-v5-c-dropdown"
         else:
-            dropdown = "#detail-content > article > div > table > :nth-child(%d)" % index + " td:last-child .pf-c-dropdown"
-        self.browser.click(dropdown + " button.pf-c-dropdown__toggle")
+            dropdown = "#detail-content > .pf-v5-c-card > div > table > :nth-child(%d)" % index + " td:last-child .pf-v5-c-dropdown"
+        self.browser.click(dropdown + " button.pf-v5-c-dropdown__toggle")
         self.browser.click(dropdown + f" a:contains('{title}')")
 
     def content_tab_expand(self, row_index, tab_index):
-        tab_btn = self.content_row_tbody(row_index) + " .pf-c-tabs ul li:nth-child(%d) button" % tab_index
+        tab_btn = self.content_row_tbody(row_index) + " .pf-v5-c-tabs ul li:nth-child(%d) button" % tab_index
         tab = self.content_row_tbody(row_index) + " .ct-listing-panel-body[data-key=%d]" % (tab_index - 1)
         self.content_row_expand(row_index)
         self.browser.click(tab_btn)
@@ -178,8 +178,8 @@ class StorageHelpers:
 
         def check():
             row = self.content_row_tbody(row_index)
-            row_item = row + " tr td.pf-c-table__toggle button"
-            tab_btn = row + " .pf-c-tabs ul li:nth-child(%d) button" % tab_index
+            row_item = row + " tr td.pf-v5-c-table__toggle button"
+            tab_btn = row + " .pf-v5-c-tabs ul li:nth-child(%d) button" % tab_index
             tab = row + " .ct-listing-panel-body[data-key=%d]" % (tab_index - 1)
             cell = tab + f" dt:contains({title}) + *"
 
@@ -238,7 +238,7 @@ class StorageHelpers:
         self.browser.wait_visible('#dialog')
 
     def dialog_wait_alert(self, text):
-        self.browser.wait_in_text('#dialog .pf-c-alert__title', text)
+        self.browser.wait_in_text('#dialog .pf-v5-c-alert__title', text)
 
     def dialog_field(self, field):
         return f'#dialog [data-field="{field}"]'
@@ -280,8 +280,8 @@ class StorageHelpers:
                 self.browser.set_checked(sel + " input[type=checkbox]", True)
                 self.browser.set_input_text(sel + " [type=text]", val)
         elif ftype == "combobox":
-            self.browser.click(sel + " button.pf-c-select__toggle-button")
-            self.browser.click(sel + f" .pf-c-select__menu li:contains('{val}') button")
+            self.browser.click(sel + " button.pf-v5-c-select__toggle-button")
+            self.browser.click(sel + f" .pf-v5-c-select__menu li:contains('{val}') button")
         else:
             self.browser.set_val(sel, val)
 
@@ -313,16 +313,19 @@ class StorageHelpers:
 
     def dialog_wait_error(self, field, val):
         # XXX - allow for more than one error
-        self.browser.wait_in_text('#dialog .pf-c-form__helper-text.pf-m-error', val)
+        self.browser.wait_in_text('#dialog .pf-v5-c-form__helper-text .pf-m-error', val)
 
     def dialog_wait_not_present(self, field):
         self.browser.wait_not_present(self.dialog_field(field))
 
     def dialog_wait_apply_enabled(self):
-        self.browser.wait_attr('#dialog button.apply', "disabled", None)
+        self.browser.wait_attr('#dialog button.apply:nth-of-type(1)', "disabled", None)
 
     def dialog_apply(self):
-        self.browser.click('#dialog button.apply')
+        self.browser.click('#dialog button.apply:nth-of-type(1)')
+
+    def dialog_apply_secondary(self):
+        self.browser.click('#dialog button.apply:nth-of-type(2)')
 
     def dialog_cancel(self):
         self.browser.click('#dialog button.cancel')
@@ -340,14 +343,14 @@ class StorageHelpers:
 
     def dialog_set_vals(self, values):
         # Sometimes a certain field needs to be set before other
-        # fields come into existence and thus the order matter that we
-        # set the fields in.  The tests however just give us a
+        # fields come into existence and thus the order matters that
+        # we set the fields in.  The tests however just give us a
         # unordered 'dict'.  Instead of changing the tests, we figure
         # out the right order dynamically here by just setting what we
         # can and then starting over.  As long as we make progress in
         # each iteration, everything is good.
         failed = {}
-        last_error = None
+        last_error = Exception
         for f in values:
             try:
                 self.dialog_set_val(f, values[f])
@@ -360,12 +363,15 @@ class StorageHelpers:
             else:
                 raise last_error
 
-    def dialog(self, values, expect={}):
+    def dialog(self, values, expect={}, secondary=False):
         self.dialog_wait_open()
         for f in expect:
             self.dialog_wait_val(f, expect[f])
         self.dialog_set_vals(values)
-        self.dialog_apply()
+        if secondary:
+            self.dialog_apply_secondary()
+        else:
+            self.dialog_apply()
         self.dialog_wait_close()
 
     def confirm(self):
@@ -432,10 +438,10 @@ class StorageHelpers:
                 "GetManagedObjects", "", [])))""")]))
 
     def configuration_field(self, dev, tab, field):
-        all = self.udisks_objects()
-        for path in all:
-            if "org.freedesktop.UDisks2.Block" in all[path]:
-                iface = all[path]["org.freedesktop.UDisks2.Block"]
+        managerObjects = self.udisks_objects()
+        for path in managerObjects:
+            if "org.freedesktop.UDisks2.Block" in managerObjects[path]:
+                iface = managerObjects[path]["org.freedesktop.UDisks2.Block"]
                 if from_udisks_ascii(iface["Device"]) == dev or from_udisks_ascii(iface["PreferredDevice"]) == dev:
                     for entry in iface["Configuration"]:
                         if entry[0] == tab:
@@ -451,11 +457,11 @@ class StorageHelpers:
         self.assertNotIn(text, self.configuration_field(dev, tab, field))
 
     def child_configuration_field(self, dev, tab, field):
-        all = self.udisks_objects()
-        for path in all:
-            if "org.freedesktop.UDisks2.Encrypted" in all[path]:
-                block_iface = all[path]["org.freedesktop.UDisks2.Block"]
-                crypto_iface = all[path]["org.freedesktop.UDisks2.Encrypted"]
+        udisks_objects = self.udisks_objects()
+        for path in udisks_objects:
+            if "org.freedesktop.UDisks2.Encrypted" in udisks_objects[path]:
+                block_iface = udisks_objects[path]["org.freedesktop.UDisks2.Block"]
+                crypto_iface = udisks_objects[path]["org.freedesktop.UDisks2.Encrypted"]
                 if from_udisks_ascii(block_iface["Device"]) == dev or from_udisks_ascii(block_iface["PreferredDevice"]) == dev:
                     for entry in crypto_iface["ChildConfiguration"]:
                         if entry[0] == tab:
@@ -469,10 +475,10 @@ class StorageHelpers:
         self.assertIn(text, self.child_configuration_field(dev, tab, field))
 
     def lvol_child_configuration_field(self, lvol, tab, field):
-        all = self.udisks_objects()
-        for path in all:
-            if "org.freedesktop.UDisks2.LogicalVolume" in all[path]:
-                iface = all[path]["org.freedesktop.UDisks2.LogicalVolume"]
+        udisk_objects = self.udisks_objects()
+        for path in udisk_objects:
+            if "org.freedesktop.UDisks2.LogicalVolume" in udisk_objects[path]:
+                iface = udisk_objects[path]["org.freedesktop.UDisks2.LogicalVolume"]
                 if iface["Name"] == lvol:
                     for entry in iface["ChildConfiguration"]:
                         if entry[0] == tab:
@@ -546,11 +552,14 @@ MakeDirectory=yes
         # the initrd is regenerated again from within the new root.
 
         self.setup_systemd_password_agent(passphrase)
+        install_items = [
+            '/etc/systemd/system/sysinit.target.wants/test-password-agent.path',
+            '/etc/systemd/system/test-password-agent.path',
+            '/etc/systemd/system/test-password-agent.service',
+            '/usr/local/bin/test-password-agent',
+        ]
         m.write("/etc/dracut.conf.d/01-askpass.conf",
-                'install_items+=" /usr/local/bin/test-password-agent ' +
-                '/etc/systemd/system/test-password-agent.service ' +
-                '/etc/systemd/system/test-password-agent.path ' +
-                '/etc/systemd/system/sysinit.target.wants/test-password-agent.path "')
+                f'install_items+=" {" ".join(install_items)} "')
 
         # The first step is to move /boot to a new unencrypted
         # partition on the new disk but keep it mounted at /boot.
@@ -558,7 +567,7 @@ MakeDirectory=yes
         # which will look at /boot and do the right thing.
         #
         # Then we copy (most of) the old root to the new disk, into a
-        # LUKS container.
+        # logical volume sitting on top of a LUKS container.
         #
         # The kernel command line is changed to use the new root
         # filesystem, and grub is installed on the new disk. The boot
@@ -582,11 +591,13 @@ parted -s {dev} mktable msdos
 parted -s {dev} mkpart primary ext4 1M 500M
 parted -s {dev} mkpart primary ext4 500M 100%
 echo {passphrase} | cryptsetup luksFormat --pbkdf-memory=300 {dev}2
-echo {passphrase} | cryptsetup luksOpen --pbkdf-memory=300 {dev}2 dm-test
 luks_uuid=$(blkid -p {dev}2 -s UUID -o value)
-mkfs.ext4 /dev/mapper/dm-test
+echo {passphrase} | cryptsetup luksOpen --pbkdf-memory=300 {dev}2 luks-$luks_uuid
+vgcreate root /dev/mapper/luks-$luks_uuid
+lvcreate root -n root -l100%VG
+mkfs.ext4 /dev/root/root
 mkdir /new-root
-mount /dev/mapper/dm-test /new-root
+mount /dev/root/root /new-root
 mkfs.ext4 {dev}1
 mkdir /new-root/boot
 mount {dev}1 /new-root/boot
@@ -598,7 +609,7 @@ umount /new-root/boot
 mount {dev}1 /boot
 echo "(hd0) {dev}" >/boot/grub2/device.map
 sed -i -e 's,/boot/,/,' /boot/loader/entries/*
-uuid=$(blkid -p /dev/mapper/dm-test -s UUID -o value)
+uuid=$(blkid -p /dev/root/root -s UUID -o value)
 buuid=$(blkid -p {dev}1 -s UUID -o value)
 echo "UUID=$uuid / auto defaults 0 0" >/new-root/etc/fstab
 echo "UUID=$buuid /boot auto defaults 0 0" >>/new-root/etc/fstab
@@ -611,13 +622,12 @@ grub2-install {dev}
   mv /boot/loader/entries.stowed /boot/loader/entries
   ! test -f /etc/kernel/cmdline.stowed || mv /etc/kernel/cmdline.stowed /etc/kernel/cmdline
 )
-grubby --update-kernel=ALL --args="root=UUID=$uuid rootflags=defaults rd.luks.uuid=$luks_uuid"
+grubby --update-kernel=ALL --args="root=UUID=$uuid rootflags=defaults rd.luks.uuid=$luks_uuid rd.lvm.lv=root/root"
 ! test -f /etc/kernel/cmdline || cp /etc/kernel/cmdline /new-root/etc/kernel/cmdline
 """, timeout=300)
-        luks_uuid = m.execute(f"blkid -p {dev}2 -s UUID -o value").strip()
         m.spawn("dd if=/dev/zero of=/dev/vda bs=1M count=100; reboot", "reboot", check=False)
         m.wait_reboot(300)
-        self.assertEqual(m.execute("findmnt -n -o SOURCE /").strip(), f"/dev/mapper/luks-{luks_uuid}")
+        self.assertEqual(m.execute("findmnt -n -o SOURCE /").strip(), "/dev/mapper/root-root")
 
 
 class StorageCase(MachineCase, StorageHelpers):
@@ -648,3 +658,8 @@ class StorageCase(MachineCase, StorageHelpers):
 
         # starting out with empty PCP logs and pmlogger not running causes these metrics channel messages
         self.allow_journal_messages("pcp-archive: no such metric: disk.*")
+
+        # UDisks2 invalidates the Size property and cockpit-bridge
+        # gets it immediately.  But sometimes the interface is already
+        # gone.
+        self.allow_journal_messages("org.freedesktop.UDisks2: couldn't get property org.freedesktop.UDisks2.Filesystem Size .* No such interface.*")
